@@ -1,5 +1,5 @@
 package App::Notifier::Service;
-$App::Notifier::Service::VERSION = '0.0900';
+$App::Notifier::Service::VERSION = '0.0901';
 use 5.014;
 
 use Mojolicious::Lite -signatures;
@@ -155,7 +155,7 @@ notifying that an event (such as the finish of a task) occured.
 
 =head1 VERSION
 
-version 0.0900
+version 0.0901
 
 =head1 SYNOPSIS
 
@@ -176,11 +176,10 @@ version 0.0900
               param_name: "msg"
     EOF
 
-    # Run the Dancer application from the distribution's root directory.
+    # Run the Mojo application from the distribution's root directory.
     plackup ./bin/app.psgi
 
     # Alternatively run the following Perl code:
-    use Dancer2 0.300003;
     use App::Notifier::Service;
     start;
 
@@ -190,7 +189,7 @@ version 0.0900
 
 =head1 AUTHOR
 
-Shlomi Fish, L<http://www.shlomifish.org/> .
+Shlomi Fish, L<https://www.shlomifish.org/> .
 
 =head1 ACKNOWLEDGEMENTS
 
